perfectns
=========

.. image:: https://travis-ci.org/ejhigson/perfectns.svg?branch=master
   :target: https://travis-ci.org/ejhigson/perfectns
.. image:: https://coveralls.io/repos/github/ejhigson/perfectns/badge.svg?branch=master
   :target: https://coveralls.io/github/ejhigson/perfectns?branch=master&service=github
.. image:: https://readthedocs.org/projects/perfectns/badge/?version=latest
   :target: http://perfectns.readthedocs.io/en/latest/?badge=latest
.. image:: http://joss.theoj.org/papers/10.21105/joss.00985/status.svg
   :target: https://doi.org/10.21105/joss.00985
.. image:: https://api.codeclimate.com/v1/badges/b04cc235c8f73870029c/maintainability
   :target: https://codeclimate.com/github/ejhigson/perfectns/maintainability
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/ejhigson/perfectns/blob/master/LICENSE

+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Read the documentation at `http://perfectns.readthedocs.io <http://perfectns.readthedocs.io>`_.
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
